=== modified file 'ivle/dispatch/__init__.py'
--- ivle/dispatch/__init__.py	2009-02-04 06:53:03 +0000
+++ ivle/dispatch/__init__.py	2009-02-04 07:18:24 +0000
@@ -51,6 +51,7 @@
 # XXX List of plugins, which will eventually be read in from conf
 plugins_HACK = [
     'ivle.webapp.admin.user#Plugin',
+    'ivle.webapp.admin.subject#Plugin',
     'ivle.webapp.browser#Plugin',
     'ivle.webapp.groups#Plugin',
     'ivle.webapp.tutorial#Plugin',

=== renamed file 'www/apps/subjects/subject_page.html' => 'ivle/webapp/admin/subject.html'
--- www/apps/subjects/subject_page.html	2009-02-02 04:00:25 +0000
+++ ivle/webapp/admin/subject.html	2009-02-04 07:18:24 +0000
@@ -1,8 +1,8 @@
 <html xmlns="http://www.w3.org/1999/xhtml"
-      xmlns:xi="http://www.w3.org/2001/XInclude"
       xmlns:py="http://genshi.edgewall.org/" py:strip="">
-
-  <body py:strip="">
-    <object class="fullscreen" type="text/html" data="${serve_loc}"></iframe>
+  <head>
+  </head>
+  <body>
+    <object class="fullscreen" type="text/html" data="${serve_loc}"></object>
   </body>
 </html>

=== renamed file 'www/apps/subjects/__init__.py' => 'ivle/webapp/admin/subject.py'
--- www/apps/subjects/__init__.py	2009-02-02 04:00:25 +0000
+++ ivle/webapp/admin/subject.py	2009-02-04 07:18:24 +0000
@@ -26,62 +26,65 @@
 import urllib
 import cgi
 
-import ivle.database
+from ivle.webapp.base.views import XHTMLView
+from ivle.webapp.base.plugins import BasePlugin
+from ivle.webapp.errors import NotFound
+from ivle.database import Subject
 from ivle import util
 
-import genshi
-import genshi.template
-
-def handle(req):
-    """Handler for the Subjects application. Links to subject home pages."""
-
-    req.styles = ["media/subjects/subjects.css"]
-    ctx = genshi.template.Context()
-    if req.path == "":
-        # This is represented as a directory. Redirect and add a slash if it is
-        # missing.
-        if req.uri[-1] != '/':
-            req.throw_redirect(req.uri + '/')
-        ctx['whichpage'] = "toplevel"
-        handle_toplevel_menu(req, ctx)
-    else:
-        ctx['whichpage'] = "subject"
-        handle_subject_page(req, req.path, ctx)
-        
-    loader = genshi.template.TemplateLoader(".", auto_reload=True)
-    tmpl = loader.load(util.make_local_path("apps/subjects/template.html"))
-    req.write(tmpl.generate(ctx).render('html')) #'xhtml', doctype='xhtml'))
-
-def handle_toplevel_menu(req, ctx):
-
-    enrolled_subjects = req.user.subjects
-    unenrolled_subjects = [subject for subject in
-                           req.store.find(ivle.database.Subject)
-                           if subject not in enrolled_subjects]
-
-    ctx['enrolled_subjects'] = []
-    ctx['other_subjects'] = []
-
-    req.content_type = "text/html"
-    req.write_html_head_foot = True
-
-    for subject in enrolled_subjects:
-        new_subj = {}
-        new_subj['name'] = subject.name
-        new_subj['url'] = subject.url
-        ctx['enrolled_subjects'].append(new_subj)
-
-    if len(unenrolled_subjects) > 0:
-        for subject in unenrolled_subjects:
+
+class SubjectsView(XHTMLView):
+    '''The view of the list of subjects.'''
+    app_template = 'subjects.html'
+    appname = 'subjects'
+
+    def populate(self, req, ctx):
+        req.styles = ["media/subjects/subjects.css"]
+
+        enrolled_subjects = req.user.subjects
+        unenrolled_subjects = [subject for subject in
+                               req.store.find(Subject)
+                               if subject not in enrolled_subjects]
+
+        ctx['enrolled_subjects'] = []
+        ctx['other_subjects'] = []
+
+        req.content_type = "text/html"
+        req.write_html_head_foot = True
+
+        for subject in enrolled_subjects:
             new_subj = {}
             new_subj['name'] = subject.name
             new_subj['url'] = subject.url
-            ctx['other_subjects'].append(new_subj)
-
-
-def handle_subject_page(req, path, ctx):
-    req.content_type = "text/html"
-    req.write_html_head_foot = True     # Have dispatch print head and foot
-
-    # Just make the iframe pointing to media/subjects
-    ctx['serve_loc'] = urllib.quote(util.make_path(os.path.join('media', 'subjects', path)))
+            ctx['enrolled_subjects'].append(new_subj)
+
+        if len(unenrolled_subjects) > 0:
+            for subject in unenrolled_subjects:
+                new_subj = {}
+                new_subj['name'] = subject.name
+                new_subj['url'] = subject.url
+                ctx['other_subjects'].append(new_subj)
+
+
+class SubjectView(XHTMLView):
+    '''The view of a subject.'''
+    app_template = 'subject.html'
+    appname = 'subjects' # XXX
+
+    def __init__(self, req, subject, path):
+        self.subject = req.store.find(Subject, code=subject).one()
+        self.path = path
+
+    def populate(self, req, ctx):
+        if self.subject is None:
+            raise NotFound()
+
+        ctx['serve_loc'] = urllib.quote(util.make_path(os.path.join('media',
+                                    'subjects', self.subject.code, self.path)))
+
+class Plugin(BasePlugin):
+    urls = [
+        ('subjects/', SubjectsView),
+        ('subjects/:subject', SubjectView, {'path': ''}),
+        ('subjects/:subject/*(path)', SubjectsView),
+    ]

=== renamed file 'www/apps/subjects/toplevel_menu.html' => 'ivle/webapp/admin/subjects.html'
--- www/apps/subjects/toplevel_menu.html	2009-02-02 04:00:25 +0000
+++ ivle/webapp/admin/subjects.html	2009-02-04 07:18:24 +0000
@@ -1,8 +1,9 @@
 <html xmlns="http://www.w3.org/1999/xhtml"
-      xmlns:xi="http://www.w3.org/2001/XInclude"
       xmlns:py="http://genshi.edgewall.org/" py:strip="">
-
-  <body py:strip="">
+  <head>
+    <title>Subjects</title>
+  </head>
+  <body>
     <div id="ivle_padding">
       <h2>IVLE Subject Homepages</h2>
       <py:if test="(len(enrolled_subjects) > 0)">

=== removed directory 'www/apps/subjects'
=== removed file 'www/apps/subjects/template.html'
--- www/apps/subjects/template.html	2009-02-02 04:00:25 +0000
+++ www/apps/subjects/template.html	1970-01-01 00:00:00 +0000
@@ -1,9 +0,0 @@
-<html xmlns="http://www.w3.org/1999/xhtml"
-      xmlns:xi="http://www.w3.org/2001/XInclude"
-      xmlns:py="http://genshi.edgewall.org/" py:strip="">
-
-  <py:choose test="whichpage">
-    <xi:include py:when="'toplevel'" href="toplevel_menu.html" />
-    <xi:include py:when="'subject'" href="subjectmenu.html" />
-  </py:choose>
-</html>

